@@ -6,7 +6,7 @@ LWP::UserAgent::Caching - HTTP::Casing based UserAgent, finally done right
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -18,22 +18,18 @@ use HTTP::Caching;
 
     use LWP::UserAgent::Caching;
     
+    my $cache = CHI->new(
+        driver          => 'File',
+        root_dir        => '/tmp/LWP_UserAgent_Caching',
+        file_extension  => '.cache',
+        l1_cache        => {
+            driver          => 'Memory',
+            global          => 1,
+            max_size        => 1024*1024
+    );
+    
     my $ua = LWP::UserAgent::Caching->new(
-        cache           => {
-            driver          => 'File',
-            root_dir        => '/tmp/LWP_UserAgent_Caching',
-            file_extension  => '.cache',
-        },
-        cache_meta      => {
-            driver          => 'File',
-            root_dir        => '/tmp/LWP_UserAgent_Caching',
-            file_extension  => '.cache',
-            l1_cache        => {
-                driver          => 'Memory',
-                global          => 1,
-                max_size        => 1024*1024
-            }
-        },
+        cache           => $cache,
         cache_type      => 'private',
         cache_control   => (
             'max-age=86400',            # 24hrs
@@ -78,9 +74,9 @@ sub new {
 
     $self->{http_caching} = HTTP::Caching->new(
         cache                   => $params{cache},
-        cache_meta              => $params{cache_meta} || $params{cache},
+#       cache_meta              => $params{cache_meta} || $params{cache},
         cache_type              => $params{cache_type} || 'private',
-#       cache_control_request   => $params{cache_control},
+        cache_control_request   => $params{cache_control},
         forwarder               => sub { $self->SUPER::request(@_) }
     );
 
